@@ -3,7 +3,7 @@
 
 __author__ = "Christoph Schranz"
 __copyright__ = "Copyright 2022, Salzburg Research"
-__version__ = "0.1.5"
+__version__ = "0.1.6"
 __maintainer__ = "Christoph Schranz, Mathias Schmoigl-Tonis"
 __credits__ = ["Christoph Schranz", "Mathias Schmoigl-Tonis"]
 
@@ -72,12 +72,11 @@ def nearest_advocate(arr_ref: np.ndarray, arr_sig: np.ndarray,
     --------
     >>> import numpy as np
     >>> import nearest_advocate
-    >>> N = 10_000 
     
     Create a reference array whose events differences are sampled from a normal distribution. The signal array is the reference but shifted by `np.pi` and addional gaussian noise. The event-timestamps of both arrays must be sorted.
     
-    >>> arr_ref = np.sort(np.cumsum(np.random.normal(loc=1, scale=0.25, size=N)))
-    >>> arr_sig = np.sort(arr_ref + np.pi + np.random.normal(loc=0, scale=0.1, size=N))
+    >>> arr_ref = np.sort(np.cumsum(np.random.normal(loc=1, scale=0.25, size=1000)))
+    >>> arr_sig = np.sort(arr_ref + np.pi + np.random.normal(loc=0, scale=0.1, size=1000))
 
     The function `nearest_advocate.nearest_advocate` returns a two-columned array with all investigated time-shifts and their mean distances, i.e., the measure of the synchronicity between both array (lower is better). 
     
@@ -95,6 +94,7 @@ def nearest_advocate(arr_ref: np.ndarray, arr_sig: np.ndarray,
     >>> plt.xlabel("Time delay (s)")
     >>> plt.ylabel("Mean distance (s)")
     >>> plt.legend(loc="lower right")
+    >>> plt.savefig("tmp.png")
     >>> plt.show()
     '''
     return _nearest_advocate(arr_ref=arr_ref, arr_sig=arr_sig, 
